<?php

namespace Newage\Printnews\Policies;

use Litepie\User\Contracts\UserPolicy;
use Newage\Printnews\Models\NewsPrint;

class NewsPrintPolicy
{

    /**
     * Determine if the given user can view the news_print.
     *
     * @param UserPolicy $user
     * @param NewsPrint $news_print
     *
     * @return bool
     */
    public function view(UserPolicy $user, NewsPrint $news_print)
    {
        if ($user->canDo('printnews.news_print.view') && $user->isAdmin()) {
            return true;
        }

        return $news_print->user_id == user_id() && $news_print->user_type == user_type();
    }

    /**
     * Determine if the given user can create a news_print.
     *
     * @param UserPolicy $user
     * @param NewsPrint $news_print
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('printnews.news_print.create');
    }

    /**
     * Determine if the given user can update the given news_print.
     *
     * @param UserPolicy $user
     * @param NewsPrint $news_print
     *
     * @return bool
     */
    public function update(UserPolicy $user, NewsPrint $news_print)
    {
        if ($user->canDo('printnews.news_print.edit') && $user->isAdmin()) {
            return true;
        }

        return $news_print->user_id == user_id() && $news_print->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given news_print.
     *
     * @param UserPolicy $user
     * @param NewsPrint $news_print
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, NewsPrint $news_print)
    {
        return $news_print->user_id == user_id() && $news_print->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given news_print.
     *
     * @param UserPolicy $user
     * @param NewsPrint $news_print
     *
     * @return bool
     */
    public function verify(UserPolicy $user, NewsPrint $news_print)
    {
        if ($user->canDo('printnews.news_print.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given news_print.
     *
     * @param UserPolicy $user
     * @param NewsPrint $news_print
     *
     * @return bool
     */
    public function approve(UserPolicy $user, NewsPrint $news_print)
    {
        if ($user->canDo('printnews.news_print.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
